import Vue from 'vue';
import Router from 'vue-router';

Vue.use(Router);

/* Layout */
import Layout from '@/layout';

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */

export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        name: 'Dashboard',
        component: () => import('@/views/dashboard/index'),
        meta: { title: '主页', role: [1, 2], icon: 'el-icon-s-home' }
      }
    ]
  },
  {
    path: '/account',
    component: Layout,
    name: 'account',
    redirect: '/account/index',
    meta: { title: '账号列表', icon: 'el-icon-menu' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/account/index'),
        meta: { title: '账号列表', role: [1, 2] }
      }
    ]
  },
  {
    path: '/entry',
    component: Layout,
    name: 'entry',
    redirect: '/entry/index',
    meta: { title: '入口列表', icon: 'el-icon-s-help' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/entry/index'),
        meta: { title: '入口列表', role: [1, 2] }
      }
    ]
  },
  {
    path: '/reservation',
    component: Layout,
    name: 'reservation',
    redirect: '/reservation/index',
    meta: { title: '预约记录', icon: 'el-icon-date' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/reservation/index'),
        meta: { title: '预约记录', role: [1, 2] }
      }
    ]
  },
  {
    path: '/personnelWhitelist',
    component: Layout,
    name: 'personnelWhitelist',
    redirect: '/personnelWhitelist/index',
    meta: { title: '人员白名单', icon: 'el-icon-user-solid' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/whitelist/index'),
        meta: { title: '人员白名单', role: [1, 2] }
      }
    ]
  },
  {
    path: '/trafficManage',
    component: Layout,
    name: 'trafficManage',
    redirect: '/trafficManage/index',
    meta: { title: '人流峰值管理', icon: 'el-icon-s-grid' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/trafficManage/index'),
        meta: { title: '人流峰值管理', role: [1, 2] }
      }
    ]
  },
  {
    path: '/guideManage',
    component: Layout,
    name: 'guideManage',
    redirect: '/guideManage/index',
    meta: { title: '预订须知管理', icon: 'el-icon-warning-outline' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/guideManage/index'),
        meta: { title: '预订须知管理', role: [1, 2] }
      }
    ]
  },
  {
    path: '/enteringThePark',
    component: Layout,
    name: 'enteringThePark',
    redirect: '/enteringThePark/index',
    meta: { title: '入园二维码', icon: 'el-icon-postcard' },
    children: [
      {
        path: 'qrCode',
        name: 'qrCode',
        component: () => import('@/views/enteringThePark/index'),
        meta: { title: '入园二维码', role: [1, 2] }
      }
    ]
  },
  {
    path: '/basicSettings',
    component: Layout,
    name: 'basicSettings',
    redirect: '/basicSettings/index',
    meta: { title: '基本设置', icon: 'el-icon-setting' },
    children: [
      {
        path: 'index',
        name: 'index',
        component: () => import('@/views/basicSettings/index'),
        meta: { title: '基本设置', role: [1, 2] }
      }
    ]
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
];
/* export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index')
  },
  {
    path: '/',
    component: Layout,
    meta: { title: '账号管理', icon: 'el-icon-menu', role: [1, 2] },
    // meta: { role: [1] },
    // redirect: '/index',
    children: [
      {
        path: '/',
        name: 'index',
        component: () => import('@/views/dashboard/index'),
        meta: { title: '内部员工账号管理', icon: 'el-icon-menu', role: [1, 2] }
      },
      {
        path: '/buy',
        name: 'buy',
        component: () => import('@/views/dashboard/buy'),
        meta: { title: '购买方账号管理', icon: 'el-icon-menu', role: [1, 2] }
      }
    ]
  },
  {
    path: '/shopList',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'shopList',
        component: () => import('@/views/shopList/index'),
        meta: { title: '商品列表', role: [2], icon: 'el-icon-notebook-2' }
      }
    ]
  },
  {
    path: '/orderRecord',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'orderRecord',
        component: () => import('@/views/orderRecord/index'),
        meta: { title: '订单记录', role: [2], icon: 'el-icon-document' }
      }
    ]
  },
  {
    path: '/statistical',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'statistical',
        component: () => import('@/views/inventory/statistical'),
        meta: { title: '库存管理', icon: 'el-icon-s-platform', role: [2, 3] }
      }
    ]
  },

  {
    path: '/InventoryRecord',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'InventoryRecord',
        component: () => import('@/views/inventory/InventoryRecord'),
        meta: { title: '入库记录', icon: 'el-icon-s-order', role: [2, 3] }
      }
    ]
  },
  {
    path: '/Outboundrecords',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'Outboundrecords',
        component: () => import('@/views/inventory/Outboundrecords'),
        meta: { title: '出库记录', icon: 'el-icon-menu', role: [2, 3] }
      }
    ]
  },
  // // {
  //   path: '/inventory',
  //   component: Layout,
  //   meta: { title: '库存管理', role: [2,3], icon: 'el-icon-s-shop' },
  //   children: [
  //     {
  //       path: 'statistical',
  //       name: 'statistical',
  //       component: () => import('@/views/inventory/statistical'),
  //       meta: { title: '库存统计', role: [2,3], icon: 'el-icon-s-platform' }
  //     },
  //     {
  //       path: 'InventoryRecord',
  //       name: 'InventoryRecord',
  //       component: () => import('@/views/inventory/InventoryRecord'),
  //       meta: { title: '入库记录', role: [2,3], icon: 'el-icon-s-order' }
  //     },
  //     {
  //       path: 'Outboundrecords',
  //       name: 'Outboundrecords',
  //       component: () => import('@/views/inventory/Outboundrecords'),
  //       meta: { title: '出库记录', role: [2,3], icon: 'el-icon-s-claim' }
  //     },
  //   ]
  // },
  {
    path: '/putStorage',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'putStorage',
        component: () => import('@/views/putStorage/index'),
        meta: { title: '自定义字段', role: [2], icon: 'el-icon-s-help' }
      }
    ]
  },
  {
    path: '/supplier',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'supplier',
        component: () => import('@/views/supplier/index'),
        meta: { title: '供应商管理', role: [2], icon: 'el-icon-s-shop' }
      }
    ]
  },
  {
    path: '/purchaser',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'purchaser',
        component: () => import('@/views/purchaser/index'),
        meta: { title: '购买方管理', role: [2], icon: 'el-icon-help' }
      }
    ]
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]; */

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes
  });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}

export default router;
