import axios from 'axios';
import { MessageBox, Message } from 'element-ui';
import store from '@/store';
import { getToken } from '@/utils/auth';
import { waitLogOut } from '@/utils/waitLogOut';

// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
  // withCredentials: false, // send cookies when cross-domain requests
  timeout: 200000 // request timeout
});

// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent

    if (store.getters.token) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers['Authorization'] = getToken();
    }
    return config;
  },
  error => {
    // do something with request error
    console.log(error); // for debug
    return Promise.reject(error);
  }
);

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
  */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    // 处理返回
    const res = response.data;
    // if the custom code is not 20000, it is judged as an error.

    if (res.code && res.code !== 200) {
      // var loginUrl = window.location.href;
      // && loginUrl.indexOf('login') == -1
      if (res.code === 401) {
        // to re-login
        MessageBox.confirm('您的登录状态已经过期啦,请重新登录吧~', '温馨提示', {
          confirmButtonText: '重新登录',
          showCancelButton: false,
          type: 'warning'
        }).then(() => {
          store.dispatch('user/logout').then(() => {
            this.$router.push(`/login`);
          });
        });
      } else {
        Message({
          message: res.msg || '出错啦~',
          type: 'error',
          duration: 5 * 1000
        });
      }
      return Promise.reject(new Error(res.msg || '出错啦~'));
    } else {
      // 超过三十分钟无操作自动退出登录
      waitLogOut();
      return res;
    }
  },
  error => {
    // console.log(error) // for debug
    Message({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    });
    return Promise.reject(error);
  }
);

export default service;
